@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::File;
 # ABSTRACT: A File data object
-$MetaCPAN::Client::File::VERSION = '1.014000';
+$MetaCPAN::Client::File::VERSION = '1.015000';
 use Moo;
 use Carp;
 
@@ -45,6 +45,21 @@ sub pod {
         );
 }
 
+sub source {
+    my $self = shift;
+
+    my $author  = $self->author;
+    my $release = $self->release;
+    my $path    = $self->path;
+
+    require MetaCPAN::Client::Request;
+
+    return
+        MetaCPAN::Client::Request->new->fetch(
+            "source/${author}/${release}/${path}"
+        );
+}
+
 
 1;
 
@@ -60,7 +75,7 @@ MetaCPAN::Client::File - A File data object
 
 =head1 VERSION
 
-version 1.014000
+version 1.015000
 
 =head1 DESCRIPTION
 
@@ -129,6 +144,12 @@ Takes a type as argument.
 
 Supported types: B<plain>, B<html>, B<x-pod>, B<x-markdown>.
 
+=head2 source
+
+    my $source = $module->source();
+
+Returns the source code for the file.
+
 =head1 AUTHORS
 
 =over 4
